// **** BEGIN LICENSE BLOCK ****
//   Copyright(c) 2009 MATSUZAWA Jiro
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
//   02110-1301, USA.  */
// **** END LICENSE BLOCK ****

var rencon;
if (!rencon) {
    rencon = {};
} else if (typeof rencon != "object") {
    throw new Error("cannot use rencon");
}

// BibRecordOutput
// BibRecordOutput is abstract class
// Temprate pattern is applied

rencon.BibRecordOutput = function()
{
    this.funcTable = new Array();
    this.record = null;
    this.settingsConf = new rencon.SettingsConf();
}

////////////////////////////////////////////////////
// public
////////////////////////////////////////////////////

// 定数
rencon.BibRecordOutput.FIRST_ITEM  = 0;
rencon.BibRecordOutput.MIDDLE_ITEM = 1;
rencon.BibRecordOutput.LAST_ITEM   = 2;

/**
 * putBibriography
 * Temprate pattern is applied.
 **/
rencon.BibRecordOutput.prototype.
putBibriography = function()
{
    this._regFunc();
    this._sortFunc();

    this._init();

    this._blockPreProc();

    // loop of putting out bibriographic record
    while (rencon.bibTable.hasNext()) {
        this.record = rencon.bibTable.getRecord();

        this._loopPreProc();
        // get method of putting out bibriographic record
        for (var i = 0; i < this.funcTable.length; i++) {
            var order;
            this.func = this.funcTable[i].getFunc();
            // first
            if (i == 0) {
                order = rencon.BibRecordOutput.FIRST_ITEM;
            }
            // last
            else if (i == this.funcTable.length-1) {
                order = rencon.BibRecordOutput.LAST_ITEM;
            }
            else {
                order = rencon.BibRecordOutput.MIDDLE_ITEM;
            }

            this.func(order);
        }
        this._loopPstProc();
    }

    this._blockPstProc();

    this._terminate();
}

////////////////////////////////////////////////////
// protected
////////////////////////////////////////////////////

/////////////////////////////////////
// methods of putting out bibriographic item
// these methods is expected to be implemented by inheritance class
rencon.BibRecordOutput.prototype.
_putTitle = function(order){}

rencon.BibRecordOutput.prototype.
_putCreator = function(order){}

rencon.BibRecordOutput.prototype.
_putPubDate = function(order){}

rencon.BibRecordOutput.prototype.
_putUrl = function(order){}

rencon.BibRecordOutput.prototype.
_putJournal = function(order){}

rencon.BibRecordOutput.prototype.
_putVolume = function(order){}

rencon.BibRecordOutput.prototype.
_putPages = function(order){}

rencon.BibRecordOutput.prototype.
_putPublisher = function(order){}

rencon.BibRecordOutput.prototype.
_blockPreProc = function(){}

rencon.BibRecordOutput.prototype.
_blockPstProc = function(){}

rencon.BibRecordOutput.prototype.
_loopPreProc = function(){}

rencon.BibRecordOutput.prototype.
_loopPstProc = function(){}

rencon.BibRecordOutput.prototype.
_init = function(){}

rencon.BibRecordOutput.prototype.
_terminate = function(){}


rencon.BibRecordOutput.prototype.
_regFunc = function()
{
    // judgh output format by page's type
    var type = rencon.SiteManager.getPageType();
    if (type == rencon.SiteManager.UNKNOWN_TYPE) {
        // regard UNKNOWN_TYPE as MIX_TYPE
        type = rencon.SiteManager.MIX_TYPE;
    }

    var titleOrder = this.settingsConf.getTitleOrder();
    if (titleOrder >= 1) {
        this.funcTable.push(new rencon.OutItem(this._putTitle, titleOrder, rencon.SettingsConf.TITLE_DEF_ORDER));
    }
    var creatorOrder = this.settingsConf.getCreatorOrder();
    if (creatorOrder >= 1) {
        this.funcTable.push(new rencon.OutItem(this._putCreator, creatorOrder, rencon.SettingsConf.CREATOR_DEF_ORDER));
    }
    var dateOrder = this.settingsConf.getPubDateOrder();
    if (dateOrder >= 1) {
        this.funcTable.push(new rencon.OutItem(this._putPubDate, dateOrder, rencon.SettingsConf.DATE_DEF_ORDER));
    }
    var urlOrder = this.settingsConf.getUrlOrder();
    if (urlOrder >= 1) {
        this.funcTable.push(new rencon.OutItem(this._putUrl, urlOrder, rencon.SettingsConf.URL_DEF_ORDER));
    }

    // only journal article type or mix type
    var jnlOrder = -1;
    var volOrder = -1;
    var pagesOrder = -1;
    if (type == rencon.SiteManager.ARTICLE_TYPE || type == rencon.SiteManager.MIX_TYPE) {
        jnlOrder = this.settingsConf.getJournalOrder();
        volOrder = this.settingsConf.getVolOrder();
        pagesOrder = this.settingsConf.getPagesOrder();
    }
    if (jnlOrder >= 1) {
        this.funcTable.push(new rencon.OutItem(this._putJournal, jnlOrder, rencon.SettingsConf.JOURNAL_DEF_ORDER));
    }
    if (volOrder >= 1) {
        this.funcTable.push(new rencon.OutItem(this._putVolume, volOrder, rencon.SettingsConf.VOL_DEF_ORDER));
    }
    if (pagesOrder >= 1) {
        this.funcTable.push(new rencon.OutItem(this._putPages, pagesOrder, rencon.SettingsConf.PAGES_DEF_ORDER));
    }

    // only monograph type or mix type
    var publisherOrder = -1;
    if (type == rencon.SiteManager.MONOGRAPH_TYPE || type == rencon.SiteManager.MIX_TYPE) {
        publisherOrder = this.settingsConf.getPublisherOrder();
    }
    if (publisherOrder >= 1) {
        this.funcTable.push(new rencon.OutItem(this._putPubVolume, publisherOrder, PUBLISHER_DEF_ORDER));
    }
}

rencon.BibRecordOutput.prototype._sortFunc = function()
{
    this.funcTable.sort( function(a, b) {
        var n = a.getOrder() - b.getOrder();
        if (n == 0) {
            return a.getDefOrder() - b.getDefOrder();
        }
        return n;
	});
}

rencon.BibRecordOutput.prototype._getTitleHeader = function()
{
    return document.getElementById("renconStringBundle").getString("titleHeader");
}

rencon.BibRecordOutput.prototype._getCreatorHeader = function()
{
    return document.getElementById("renconStringBundle").getString("creatorHeader");
}

rencon.BibRecordOutput.prototype._getPubDateHeader = function()
{
    return document.getElementById("renconStringBundle").getString("pubDateHeader");
}

rencon.BibRecordOutput.prototype._getUrlHeader = function()
{
    return document.getElementById("renconStringBundle").getString("urlHeader");
}

rencon.BibRecordOutput.prototype._getJournalHeader = function()
{
    return document.getElementById("renconStringBundle").getString("journalHeader");
}

rencon.BibRecordOutput.prototype._getVolumeHeader = function()
{
    return document.getElementById("renconStringBundle").getString("volumeHeader");
}

rencon.BibRecordOutput.prototype._getPagesHeader = function()
{
    return document.getElementById("renconStringBundle").getString("pagesHeader");
}

rencon.BibRecordOutput.prototype._getPublisherHeader = function()
{
    return document.getElementById("renconStringBundle").getString("publisherHeader");
}
