// **** BEGIN LICENSE BLOCK ****
//   Copyright(c) 2009 MATSUZAWA Jiro
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
//   02110-1301, USA.  */
// **** END LICENSE BLOCK ****

var rencon;
if (!rencon) {
    rencon = {};
} else if (typeof rencon != "object") {
    throw new Error("cannot use rencon");
}

// NDL-OPAC Periodicals index parser

// This class implement PageParser
// Singleton pattern is applied

////////////////////////////////////////////////////
// public
////////////////////////////////////////////////////

rencon.NdlPeriodicalsIndex = function()
{
}

rencon.NdlPeriodicalsIndex.getInstance = function()
{
    if (rencon.NdlPeriodicalsIndex.instance == null) {
        rencon.NdlPeriodicalsIndex.instance = new rencon.NdlPeriodicalsIndex();
    }
    return rencon.NdlPeriodicalsIndex.instance;
}


rencon.NdlPeriodicalsIndex.prototype.pickoutBibRecord = function()
{
    var recList = this.getRecordInf();

    for ( var i = 0; i < recList.length; i++) {
        var rec = new rencon.ArticleRecord();
        var trs = recList[i].getElementsByTagName("tr");
        if (!trs) {
            throw new Error("no records");
        }
        if (trs[0].getElementsByTagName("font")[1].firstChild.nodeType != Node.TEXT_NODE ||
            trs[1].getElementsByTagName("font")[0].firstChild.nodeType != Node.TEXT_NODE )
        {
            throw new Error("No Title Part OR No Journal Part");
        }
        var titlePart = trs[0].getElementsByTagName("font")[1].firstChild.data;
        var jnlPart = trs[1].getElementsByTagName("font")[0].firstChild.data;

        try {

        rec.setTitle(this.pickoutTitle(titlePart));
        rec.setCreator(this.pickoutCreator(titlePart));
        rec.setJournal(this.pickoutJournal(jnlPart));
        rec.setVolume(this.pickoutVolume(jnlPart));
        rec.setPubDate(this.pickoutPubDate(jnlPart));

        rencon.bibTable.addRecord(rec);

        } catch(e) {

        alert(e);

        }
    }
}

////////////////////////////////////////////////////
// private
////////////////////////////////////////////////////

rencon.NdlPeriodicalsIndex.SEPARATOR_TITLE_PART        = " / ";
rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_JOURNAL_1ST = /\.\s\S.*\s\[.*\d+.*\]$/g;
rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_JOURNAL_2ND = /\.\s\S.*\d+.*$/g;
rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_VOLUME_1ST  = /\s\[.*\d+.*\]$/g;
rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_VOLUME_2ND  = rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_JOURNAL_2ND;
rencon.NdlPeriodicalsIndex.instance = null;

rencon.NdlPeriodicalsIndex.prototype.getRecordInf = function()
{
    var recInf =  window._content.document.body.getElementsByTagName("form")[6].getElementsByTagName("dl")[0].getElementsByTagName("table");

    if (!recInf) {
        throw new Error("no records information");
    }

    return recInf;
}

rencon.NdlPeriodicalsIndex.prototype.
pickoutTitle = function(
        src
        )
{
    var idx = src.lastIndexOf(rencon.NdlPeriodicalsIndex.SEPARATOR_TITLE_PART);

    // assume this line is only title part because there is no creator part
    if (idx < 0 ) {
        return src;
    }

    return src.slice(0, idx);
}


rencon.NdlPeriodicalsIndex.prototype.
pickoutCreator = function(
        src
        )
{
    var idx = src.lastIndexOf(rencon.NdlPeriodicalsIndex.SEPARATOR_TITLE_PART);

    // no creator
    if (idx < 0 ) {
        return ""
    }

    idx = idx + rencon.NdlPeriodicalsIndex.SEPARATOR_TITLE_PART.length;
    return src.slice(idx);
}

rencon.NdlPeriodicalsIndex.prototype.
pickoutPubDate = function(
        src
        )
{
    var regex       = null;
    var candidate   = null;
    var tmp         = null;
    var bool        = false;
    var headIdx     = -1;
    var tailIdx     = -1;

    // if first regex dose not match src, use second regex
    regex = rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_VOLUME_1ST;
    bool = regex.test(src);
    // reset lastIndex which has been updated by test()
    regex.lastIndex = 0;
    if (bool == false) {
        regex = rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_VOLUME_2ND;
    }

    // search most right and shortest part matched
    while ( (tmp = regex.exec(src)) != null) {
        candidate = tmp;
        regex.lastIndex = tmp.index + 1;
    }
    regex.lastIndex = 0;

    if (candidate == null) {
        return "";
    }

    switch (regex) {
	case rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_VOLUME_1ST :
		headIdx = candidate.index + 2;
		tailIdx = src.length - 1;
		break;

	case rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_VOLUME_2ND :
		headIdx = candidate.index + 2;
		tailIdx = src.length;
		break;

	defalut :
		return "";
    }

    return src.slice(headIdx, tailIdx);
}

rencon.NdlPeriodicalsIndex.prototype.
pickoutJournal = function(
        src
        )
{
    var regex       = null;
    var tmp         = null;
    var candidate   = null;
    var bool        = false;

    // if first regex dose not match src, use second regex
    regex = rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_JOURNAL_1ST;
    bool = regex.test(src);
    // reset lastIndex which has been updated by test()
    regex.lastIndex = 0;
    if (bool == false) {
        regex = rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_JOURNAL_2ND;
    }

    // search most right and shortest part matched 
    //   by keeping that journal'tiltle includee '. ' in mind
    while ( (tmp = regex.exec(src)) != null) {
        candidate = tmp;
        regex.lastIndex = tmp.index + 1;
    }
    regex.lastIndex = 0;

    if (candidate == null) {
        return "";
    }

    return src.slice(0, candidate.index);
}

rencon.NdlPeriodicalsIndex.prototype.pickoutVolume = function(
        src
        )
{
    var headIdx     = -1;
    var tailIdx     = -1;
    var regex       = null;
    var tmp         = null;
    var candidate   = null;
    var bool        = false;

    // if first regex dose not match src, use second regex
    regex = rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_JOURNAL_1ST;
    bool = regex.test(src);
    // reset lastIndex which has been updated by test()
    regex.lastIndex = 0;
    if (bool == false) {
        regex = rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_JOURNAL_2ND;
    }

    while ( (tmp = regex.exec(src)) != null) {
        candidate = tmp;
        regex.lastIndex = tmp.index + 1;
    }
    regex.lastIndex = 0;

    if (candidate == null) {
        return "";
    }

    headIdx = candidate.index + 2;
    switch (regex) {
	case rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_JOURNAL_1ST :
		var regVol = rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_VOLUME_1ST;
		var candVol = null;
		while ( (tmp = regVol.exec(src)) != null) {
			candVol = tmp;
			regVol.lastIndex = tmp.index + 1;
		}
		regVol.lastIndex = 0;
		tailIdx = candVol.index;
		break;

	case rencon.NdlPeriodicalsIndex.REGEX_SEPARATOR_JOURNAL_2ND :
		tailIdx = src.length;
		break;

	default :
		return "";
    }

    return src.slice(headIdx, tailIdx);
}
