// **** BEGIN LICENSE BLOCK ****
//   Copyright(c) 2009 MATSUZAWA Jiro
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
//   02110-1301, USA.  */
// **** END LICENSE BLOCK ****

var rencon;
if (!rencon) {
    rencon = {};
} else if (typeof rencon != "object") {
    throw new Error("Rencon cannot run");
}

rencon.SettingsConf = function()
{
    this.conf = new rencon.Config();
    try {
        this.conf.read(rencon.SettingsConf.getConfigName());
    } catch(e) {
        ;
    }
}

rencon.SettingsConf.TITLE_DEF_ORDER     = 1;
rencon.SettingsConf.CREATOR_DEF_ORDER   = 2;
rencon.SettingsConf.JOURNAL_DEF_ORDER   = 3;
rencon.SettingsConf.VOL_DEF_ORDER       = 4;
rencon.SettingsConf.PUBLISHER_DEF_ORDER = 5;
rencon.SettingsConf.DATE_DEF_ORDER      = 6;
rencon.SettingsConf.PAGES_DEF_ORDER     = 7;
rencon.SettingsConf.URL_DEF_ORDER       = 8;

rencon.SettingsConf.getConfigName = function()
{
    var id = "rencon@mozdev.org";
    var ext = Components.classes["@mozilla.org/extensions/manager;1"]
                .getService(Components.interfaces.nsIExtensionManager)
                .getInstallLocation(id).getItemLocation(id); 
    var dlm = rencon.System.pathDelimiter();
    return ext.path + dlm + "conf" + dlm + "settings.conf";
}

rencon.SettingsConf.prototype = {
///////////////////////////////////////////////////
// public
///////////////////////////////////////////////////
    getSeparator : function()
    {
        var sep = this.conf.getValue("separator");
        var valPtn = /^[,:; ]$/;
        if (sep == "\\t") {
            return "\t";
        } else if (valPtn.test(sep)) {
            return sep;
        }
        sep = this.conf.getValue("otherSeparator");
        if (!sep) {
            return "\t";
        }
        return sep;
    },


    getHeader : function()
    {
        return this.conf.getValue("header") == "0" ? 0 : 1;
    },

    getTitleOrder : function()
    {
        var order = this.getItemOrder("title");
        return order ? order : rencon.SettingsConf.TITLE_DEF_ORDER;
    },


    getCreatorOrder : function()
    {
        var order = this.getItemOrder("creator");
        return order ? order : rencon.SettingsConf.CREATOR_DEF_ORDER;
    },


    getJournalOrder : function()
    {
        var order = this.getItemOrder("journal");
        return order ? order : rencon.SettingsConf.JOURNAL_DEF_ORDER;
    },


    getVolOrder : function()
    {
        var order = this.getItemOrder("vol");
        return order ? order : rencon.SettingsConf.VOL_DEF_ORDER;
    },


    getPublisherOrder : function()
    {
        var order = this.getItemOrder("publisher");
        return order ? order : rencon.SettingsConf.PUBLISHER_DEF_ORDER;
    },


    getPubDateOrder : function()
    {
        var order = this.getItemOrder("pubDate");
        return order ? order : rencon.SettingsConf.DATE_DEF_ORDER;
    },


    getPagesOrder : function()
    {
        var order = this.getItemOrder("pages");
        return order ? order : rencon.SettingsConf.PAGES_DEF_ORDER;
    },


    getUrlOrder : function()
    {
        var order = this.getItemOrder("url");
        return order ? order : rencon.SettingsConf.URL_DEF_ORDER;
    },


    getHowToSave : function()
    {
        var how = this.conf.getValue("howToSave");
        if (how == "userDir") {
            return how;
        }
        return "ask";
    },


    getSaveDir : function()
    {
        return this.conf.getValue("saveDir");
    },


    getEncoding : function()
    {
        var encoding = this.conf.getValue("encoding");
        if (!encoding) {
            encoding = "UTF-8";
        }
        return encoding;
    },

///////////////////////////////////////////////////
// private
///////////////////////////////////////////////////
    getItemOrder : function(
        item
        )
    {
        var order = this.conf.getValue(item + "Order");
        var valOrder = /[1-8]/;
        if (order && valOrder.test(order)) {
            return Number(order);
        }
        return 0;
    },

};
