// **** BEGIN LICENSE BLOCK ****
//   Copyright(c) 2009 MATSUZAWA Jiro
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
//   02110-1301, USA.  */
// **** END LICENSE BLOCK ****

var rencon;
if (!rencon) {
    rencon = {};
} else if (typeof rencon != "object") {
    throw new Error("");
}

rencon.SiteManager = function()
{
}

////////////////////////////////////////////////////
// public
////////////////////////////////////////////////////

///////////////////////////
// class method
///////////////////////////

rencon.SiteManager.createParser = function()
{
    if (rencon.SiteManager._isNdlPeriodicalsIndex()) {
        return rencon.NdlPeriodicalsIndex.getInstance();
    } else if (rencon.SiteManager._isCiNiiSearch()) {
        return rencon.CiNiiSearchParser.getInstance();
    }

    return null;
}

rencon.SiteManager.getPageType = function()
{
    var page = rencon.SiteManager.judgeSite();

    switch (page) {
	case rencon.SiteManager.NDL_PERIODICALS_INDEX:
    case rencon.SiteManager.CINII_SEARCH:
		return rencon.SiteManager.ARTICLE_TYPE;

	default :
		return rencon.SiteManager.UNKNOWN_TYPE;
    }
}


rencon.SiteManager.judgeSite = function()
{
    if (rencon.SiteManager._isNdlPeriodicalsIndex()) {
        return rencon.SiteManager.NDL_PERIODICALS_INDEX;
    } else if (rencon.SiteManager._isCiNiiSearch()) {
        return rencon.SiteManager.CINII_SEARCH;
    }

    return rencon.SiteManager.UNKNOWN_SITE;
}


///////////////////////////
// class property
///////////////////////////

// site identification constant
rencon.SiteManager.NDL_PERIODICALS_INDEX   = 1;
rencon.SiteManager.CINII_SEARCH            = 2;
rencon.SiteManager.UNKNOWN_SITE            = -1;

// bibriographic type constant
rencon.SiteManager.ARTICLE_TYPE    = 1;
rencon.SiteManager.MONOGRAPH_TYPE  = 2;
rencon.SiteManager.MIX_TYPE        = 3;
rencon.SiteManager.UNKNOWN_TYPE    = -1;


////////////////////////////////////////////////////
// private
////////////////////////////////////////////////////

///////////////////////////
// class method
///////////////////////////

rencon.SiteManager._isNdlPeriodicalsIndex = function()
{
    var _NDL_PERIODICALS_INDEX_TITLE_JA = "国立国会図書館 NDL-OPAC(雑誌記事索引 一覧表示)";
//    var _NDL_PERIODICALS_INDEX_TITLE_EN = "National Diet Library NDL-OPAC(Results (Japanese Periodicals Index))";

    if (window._content.document.title.localeCompare(_NDL_PERIODICALS_INDEX_TITLE_JA) == 0) {
        return true;
//    } else if (window._content.document.title == _NDL_PERIODICALS_INDEX_TITLE_EN) {
//        return true;
    }
    return false;
}

rencon.SiteManager._isCiNiiSearch = function()
{
    var ciNiiTitlePatternJa = /^CiNii 検索/;
    var ciNiiTitlePatternEn = /^CiNii Search/;
    var title = window._content.document.title;

    if (ciNiiTitlePatternJa.test(title)) {
        return true;
    } else if (ciNiiTitlePatternEn.test(title)) {
        return true;
    }
    return false;
}
